#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   tagHelper.py
@Time    :   2019/07/18
@Author  :   Yaron Huang 
@Version :   1.0
@Contact :   yaronhuang@qq.com
@Desc    :   
'''
import os
import sys
from mutagen import File
from mutagen import flac
from mutagen import mp4
from mutagen.id3 import TALB, TCOP, TDRC, TIT2, TPE1, TRCK, APIC, TOPE, TCON

def _getHash(pHash, key):
    if key in pHash:
        return pHash[key]
    return ''

def _lower(input):
    if isinstance(input,str):
        input = input.decode('utf-8')
    input = input.lower().encode('utf-8')
    return input

def _getExtension(filepath):
    index = filepath.rfind('.')
    ret = filepath[index + 1:len(filepath)]
    v = sys.version_info
    if v[0] > 2:
        return str.lower(ret)
    else:
        return _lower(ret)

def _getFileData(filepath):
    try:
        with open(filepath, "rb") as f:
            data = f.read()
            return data
    except:
        return None

def _tryInt(obj):
    try:
        ret = int(obj)
        return ret
    except:
        return 0

def _getArrayStr(array):
    if len(array) <= 0:
        return array
    ret = None
    for item in array:
        if ret is None:
            ret = item
            continue
        ret += ';' + item
    return ret

class TagTool(object):
    def __init__(self, filePath):
        if os.path.isfile(filePath) is False:
            return

        self._filepath = filePath
        self._ext = _getExtension(filePath)
        self._handle = File(filePath)

        self.title = ''
        self.album = ''
        self.albumartist = ''
        self.artist = ''
        self.copyright = ''
        self.tracknumber = ''
        self.totaltrack = ''
        self.discnumber = ''
        self.totaldisc = ''
        self.genre = ''
        self.date = ''

    def save(self, coverPath=None):
        try:
            if 'mp3' in self._ext:
                return self._saveMp3(coverPath)
            if 'flac' in self._ext:
                return self._saveFlac(coverPath)
            if 'mp4' in self._ext or 'm4a' in self._ext:
                return self._saveMp4(coverPath)
            return False
        except:
            return False

    def _saveMp3(self, coverPath):
        self._handle.tags.add(TIT2(encoding=3, text=self.title))
        self._handle.tags.add(TALB(encoding=3, text=self.album))
        # self._handle.tags.add(TOPE(encoding=3, text=self.albumartist))
        self._handle.tags.add(TPE1(encoding=3, text=self.artist))
        self._handle.tags.add(TCOP(encoding=3, text=self.copyright))
        self._handle.tags.add(TRCK(encoding=3, text=str(self.tracknumber)))
        # self._handle.tags.add(TRCK(encoding=3, text=self.discnum))
        self._handle.tags.add(TCON(encoding=3, text=self.genre))
        self._handle.tags.add(TDRC(encoding=3, text=self.date))
        self._savePic(coverPath)
        self._handle.save()
        return True

    def _saveFlac(self, coverPath):
        if self._handle.tags is None:
            self._handle.add_tags()
        self._handle.tags['title'] = self.title
        self._handle.tags['album'] = self.album
        self._handle.tags['albumartist'] = self.albumartist
        self._handle.tags['artist'] = self.artist
        self._handle.tags['copyright'] = self.copyright
        self._handle.tags['tracknumber'] = str(self.tracknumber)
        self._handle.tags['tracktotal'] = str(self.totaltrack)
        self._handle.tags['discnumber'] = str(self.discnumber)
        self._handle.tags['disctotal'] = str(self.totaldisc)
        self._handle.tags['genre'] = self.genre
        self._handle.tags['date'] = self.date
        self._savePic(coverPath)
        self._handle.save()
        return True
    
    def _saveMp4(self, coverPath):
        self._handle.tags['\xa9nam'] = self.title
        self._handle.tags['\xa9alb'] = self.album
        self._handle.tags['aART'] = _getArrayStr(self.albumartist)
        self._handle.tags['\xa9ART'] = _getArrayStr(self.artist)
        self._handle.tags['cprt'] = self.copyright
        self._handle.tags['trkn'] = [[_tryInt(self.tracknumber), _tryInt(self.totaltrack)]]
        self._handle.tags['disk'] = [[_tryInt(self.discnumber), _tryInt(self.totaldisc)]]
        self._handle.tags['\xa9gen'] = self.genre
        self._handle.tags['\xa9day'] = self.date
        self._savePic(coverPath)
        self._handle.save()
        return True

    def _savePic(self, coverPath):
        data = _getFileData(coverPath)
        if data is None:
            return
        if 'flac' in self._ext:    
            pic = flac.Picture()
            pic.data = data
            self._handle.clear_pictures()
            self._handle.add_picture(pic)
        if 'mp3' in self._ext:
            self._handle.tags.add(APIC(encoding=3, data=data))
        if 'mp4' in self._ext or 'm4a' in self._ext:
            pic = mp4.MP4Cover(data)
            self._handle.tags['covr'] = [pic]


# test = TagTool('e:\\1.m4a')
# test.album = ['ff']
# test.albumartist = ['yaron', 'f']
# test.artist = ['huang', 'dd']
# test.copyright = 'fasd'
# test.title = 'yes'
# test.tracknumber = '1'
# test.genre = 'fdsa'
# test.date = '2019-2-3'
# test.save('e:\\1.jpg')
# y =str.lower("Ye")

# t = str("Ye").lower()
# a = o





#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   pipHelper.py
@Time    :   2019/03/11
@Author  :   Yaron Huang 
@Version :   1.0
@Contact :   yaronhuang@qq.com
@Desc    :   pip server tool
'''

import aigpy.netHelper as netHelper

def getInfo(projectName):
    """
    #Func    :   获取pip上项目的信息                                                              
    #Param   :   projectName      [in] 项目名                                                     
    #Return  :   json or None                              
    """
    url = 'https://pypi.org/pypi/' + projectName + '/json'
    ret = netHelper.downloadJson(url,None)
    return ret
    
def getLastVersion(projectName):
    """
    #Func    :   获取pip上项目的最新的版本号                                                                      
    #Param   :   projectName      [in] 项目名                                                     
    #Return  :   Err:None                               
    """
    try:
        ret = getInfo(projectName)
        if ret is None:
            return None
        return ret['info']['version']
    except:
        return None

def getVersionList(projectName):
    """
    #Func    :   获取pip上项目的全部版本信息                                                                 
    #Param   :   projectName      [in] 项目名                                                     
    #Return  :   数组 or None                               
    """
    try:
        ret = getInfo(projectName)
        if ret is None:
            return None
        return ret['releases']
    except:
        return None



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@File    :   versionHelper.py
@Time    :   2018/12/20
@Author  :   Yaron Huang 
@Version :   1.0
@Contact :   yaronhuang@qq.com
@Desc    :   Vsesion Tool
'''

import os
import platform
import aigpy.configHelper as ConfigHelper

def getVersion(in_filepath):
    try:
        if os.path.isfile(in_filepath) is False:
            return ""
        if os.path.exists(in_filepath) is False:
            return ""
        
        # get system
        sysName = platform.system()
        if sysName == "Windows":
            import win32api
            info    = win32api.GetFileVersionInfo(in_filepath, os.sep)
            ms      = info['FileVersionMS']
            ls      = info['FileVersionLS']
            version = '%d.%d.%d.%04d' % (win32api.HIWORD(ms), win32api.LOWORD(ms), win32api.HIWORD(ls), win32api.LOWORD(ls))
            return version
        if sysName == "Linux":
            return ""
        return ""
    except:
        return ""

def cmpVersion(ver1, ver2):
    vlist1 = ver1.split('.')
    vlist2 = ver2.split('.')
    iIndex = 0
    for obj in vlist1:
        if len(vlist2) <= iIndex:
            break
        if obj > vlist2[iIndex]:
            return 1
        if obj < vlist2[iIndex]:
            return -1
        iIndex = iIndex + 1
    return 0


class VersionFile(object):
    def __init__(self, path = None): 
        self.version      = None
        self.mainFile     = None
        self.elseFileList = []
        self.isZip        = 0
        self.zipFile      = ''        
        if path != None:
            self.readFile(path)

    def saveFile(self, path):
        if path is None or self.version is None or self.mainFile is None:
            return False
        if self.isZip != 0 and self.zipFile == '':
            return False

        check = ConfigHelper.SetValue('common', 'version',  self.version, path)
        check = ConfigHelper.SetValue('common', 'mainfile', self.mainFile, path)
        if check is False:
            return False
        check = ConfigHelper.SetValue('common', 'iszip',  self.isZip, path)
        check = ConfigHelper.SetValue('common', 'zipfile',  self.isZip, path)

        if self.elseFileList is None or len(self.elseFileList) == 0:
            return True
        ConfigHelper.SetValue('common', 'elsenum', len(self.elseFileList), path)
        index = 0
        for item in self.elseFileList:
            ConfigHelper.SetValue('common', 'else' + index, item, path)
            index = index + 1
        return True

    def readFile(self, path):
        if path is None:
            return False
        ver      = ConfigHelper.GetValue('common', 'version', '', path)
        mainFile = ConfigHelper.GetValue('common', 'mainfile', '', path)
        if ver == '' or mainFile == '':
            return False

        isZip   = ConfigHelper.GetValue('common', 'iszip', 0, path)
        isZip   = int(isZip)
        zipFile = ConfigHelper.GetValue('common', 'zipfile', '', path)
        if isZip != 0 or zipFile == '':
            return False

        elseNum  = ConfigHelper.GetValue('common', 'elsenum', 0, path)
        elseNum  = int(elseNum)
        elseList = []
        index    = 0
        if elseNum > 0:
            obj   = ConfigHelper.GetValue('common', 'else' + index, '', path)
            index = index + 1
            elseList.append(obj)
        
        self.version      = ver
        self.mainFile     = mainFile
        self.elseFileList = elseList
        self.isZip        = isZip
        self.zipFile      = zipFile
        return True



# -*- coding: utf-8 -*-
from colorama import init
import socks
import requests
import sys
import time

sys.path.append('./')
import aigpy.zipHelper as zipHelper
from aigpy.updateHelper import updateTool
import aigpy.ffmpegHelper as ffmpegHelper
from aigpy.serverHelper import ServerTool


if __name__ == '__main__':
    init(autoreset=True)
    print("\033[0;30;40m\tHello World\033[0m")  # 黑色
    print("\033[0;31;40m\tHello World\033[0m")  # 红色
    print("\033[0;32;40m\tHello World\033[0m")  # 绿色
    print("\033[0;33;40m\tHello World\033[0m")  # 黄色
    print("\033[0;34;40m\tHello World\033[0m")  # 蓝色
    print("\033[0;35;40m\tHello World\033[0m")  # 紫色
    print("\033[0;36;40m\tHello World\033[0m")  # 浅蓝
    print("\033[0;37;40m\tHello World\033[0m")  # 白色



from setuptools import setup, find_packages
import sys

if sys.version_info >= (3, 0):
    install_requires = ["requests", "configparser", "colorama", "mutagen"]
else:
    install_requires = ["requests", "configparser", "colorama", "futures", "mutagen"]

setup(
    name = 'aigpy',
    version='2019.8.5.1',
    license = "MIT Licence",
    description = "Python Common Tool",

    author = 'YaronH',
    author_email = "yaronhuang@qq.com",

    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires=install_requires,
    # entry_points={'console_scripts': [
    #     'tidal-dl = tidal_dl:main', ]}
)



#!/usr/bin/env python
# -*- encoding: utf-8 -*-

'''
@File    :   netHelper.py
@Time    :   2018/12/17
@Author  :   Yaron Huang 
@Version :   1.0
@Contact :   yaronhuang@qq.com
@Desc    :   
'''

import sys
import requests
import json
from socket import *

def downloadString(url, timeouts=(3.05, 27)):
    """
    #Func    :   下载字符串        
    #Param   :   url        [in] 链接       
    #Param   :   timeouts   [in] 超时             
    #Return  :   Err:None              
    """
    try:
        re = requests.get(url, timeouts)
        return re.content
    except:
        return None 
    

def downloadJson(url, timeouts=(3.05, 27)):
    """
    #Func    :   下载json   
    #Param   :   url        [in] 链接       
    #Param   :   timeouts   [in] 超时       
    #Return  :   Err:None       
    """
    try:
        re = requests.get(url, timeouts)
        info = json.loads(re.content)
        return info
    except:
        return None

def getFileSize(url):
    """
    #Func    :   获取文件大小       
    #Param   :   url    [in] 链接           
    #Return  :   Err:-1     
    """
    if sys.version_info > (3, 0):
        from urllib.request import urlopen
    else:
        from urllib2 import urlopen

    try:
        response = urlopen(url)
        info     = response.info()
        dic      = dict(info)
        length   = dic['Content-Length']
        return int(length)
    except:
        return -1

def downloadFile(url, fileName, stimeout=None):
    """
    #Func    :   下载文件              
    #Param   :   url        [in] 链接       
    #Param   :   fileName   [in] 文件路径              
    #Return  :   True/False            
    """
    if sys.version_info > (3,0):
        from urllib.request import urlopen
    else:
        from urllib2 import urlopen
    
    try:
        if timeout is None:
            response = urlopen(url)
        else:
            response = urlopen(url, timeout=stimeout)

        chunksize = 16 * 1024
        with open(fileName, 'wb') as f:
            while True:
                chunk = response.read(chunksize)
                if not chunk:
                    break
                f.write(chunk)
            return True
    except:
        return False

def getIpStatus(host, port, timeouts=1):
    """
    #Func    :   测试连接              
    #Param   :   host        [in] IP地址       
    #Param   :   port        [in] 端口       
    #Param   :   timeouts    [in] 超时       
    #Return  :   True/False       
    """
    setdefaulttimeout(timeouts)
    flag = True
    try:
        s = socket(AF_INET, SOCK_STREAM)
        s.connect((host, port))
        s.close()
    except:
        flag = False
    return flag


# bo = downloadFile('http://down.2zzt.com/uploads/cu/cu2.3.zip', 'e:\\1.zip')
# t = 1